@@ -14,9 +14,17 @@ class InvalidWindowArgument(BaseOrcaException):
     """Raised when an argument to the Window class is not valid"""
 
 
+class InvalidMetadataFieldArgument(BaseOrcaException):
+    """Raised when an argument to a metadata field is not valid"""
+
+
 class InvalidDependency(BaseOrcaException):
     """Raised when a dependency is invalid"""
 
 
-class MissingDependency(BaseOrcaException):
-    """Raised when a dependency is missing"""
+class MissingEnvVar(BaseOrcaException):
+    """Raised when an environment variable is missing"""
+
+
+class BadEnvVar(BaseOrcaException):
+    """Raised when an environment variable is poorly defined"""
